@@ -17,6 +17,7 @@ export * from './Gridbox'
 export * from './Hinted'
 export * from './Image'
 export * from './ImageView'
+export * from './MenuButton'
 export * from './LazyText'
 export * from './StoredImagesList'
 export * from './LabeledSelect'
@@ -28,6 +29,7 @@ export * from './MaterialIcon'
 export * from './Notification'
 export * from './OptionsList'
 export * from './PasswordSetter'
+export * from './RelIcon'
 export * from './Ruler'
 export * from './Lists'
 export * from './Spacing'
