@@ -1,4 +1,4 @@
-import {ThemeOptions} from '@mui/material'
+import {ThemeOptions, Components} from '@mui/material'
 
 
 const primaryColor = '#0070f0'
@@ -7,6 +7,10 @@ const disabledColor = '#00000044'
 const hintColor = '#4488ff'
 
 
+export type WeframComponents = {
+
+}
+
 export interface WorkspaceTheme extends ThemeOptions {
   colors: {
     primaryColor: string,
@@ -25,7 +29,9 @@ export interface WorkspaceTheme extends ThemeOptions {
     error: string
     info: string
     warning: string
-  }
+  },
+
+  weframComponents: WeframComponents
 }
 
 
@@ -87,6 +93,10 @@ const workspaceTheme: WorkspaceTheme = {
     }
   },
 
+  weframComponents: {
+
+  },
+
   components: {
     MuiAlert: {
       styleOverrides: {
